cmd

package
v0.3.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

README

cmd

This directory contains the source code for the r2 CLI, which leverages the Cobra CLI framework.

Architecture

  • root.go contains the root command that is executed when r2 is run
  • configure.go contains the configure command
  • cp.go contains the cp command
  • ls.go contains the ls command
  • mb.go contains the mb command
  • mv.go contains the mv command
  • presign.go contains the presign command
  • rb.go contains the rb command
  • rm.go contains the rm command
  • sync.go contains the sync command

Documentation

Index

Constants

This section is empty.

Variables

var R2ConfigFile = getConfigPath()

R2ConfigFile globally defines the path to the ~/.r2 configuration file.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

This section is empty.

Jump to